@@ -38,6 +38,19 @@ sub foo2 : Global {
     $c->forward('TestApp::View::JSON');
 }
 
+sub foo3 : Global {
+    my( $self, $c ) = @_;
+    $c->stash->{json_foo} = "\x{5bae}\x{5ddd}";
+    $c->forward('TestApp::View::JSON');
+}
+
+sub foo4 : Global {
+    my( $self, $c ) = @_;
+    $c->stash->{json_foo} = "\x{5bae}\x{5ddd}";
+    $c->component('View::JSON')->encoding('euc-jp');
+    $c->forward('TestApp::View::JSON');
+}
+
 sub finalize_error {
     my $c = shift;
     $c->res->header('X-Error' => $c->error->[0]);
